==> haskell-ghc-typelits-natnormalise-0.7.12-2.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-typelits-natnormalise
version:              0.7.12
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.12-ID8plq7KcvWHB1mPTHwLeK
key:                  ghc-typelits-natnormalise-0.7.12-ID8plq7KcvWHB1mPTHwLeK
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  093dd2182b1f56658a0ceda8492c340a
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-typelits-natnormalise-0.7.12

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-typelits-natnormalise-0.7.12

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/ghc-typelits-natnormalise-0.7.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-natnormalise
hs-libraries:         HSghc-typelits-natnormalise-0.7.12-ID8plq7KcvWHB1mPTHwLeK
depends:
    base-4.18.2.1 containers-0.6.7 ghc-9.6.6 ghc-bignum-1.3
    ghc-tcplugins-extra-0.5-Gk013ZGNPeb6zZ5XpIVmns
    template-haskell-2.20.0.0 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-natnormalise-0.7.12-3-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-typelits-natnormalise
version:              0.7.12
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.12-4A61GQNMhINCZAlCrgN5bt
key:                  ghc-typelits-natnormalise-0.7.12-4A61GQNMhINCZAlCrgN5bt
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  ec8934f9752e27d3c7a173a3fcb452c7
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-typelits-natnormalise-0.7.12

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/ghc-typelits-natnormalise-0.7.12

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/ghc-typelits-natnormalise-0.7.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-natnormalise
hs-libraries:         HSghc-typelits-natnormalise-0.7.12-4A61GQNMhINCZAlCrgN5bt
depends:
    base-4.18.2.1 containers-0.6.7 ghc-9.6.6 ghc-bignum-1.3
    ghc-tcplugins-extra-0.5-Gk013ZGNPeb6zZ5XpIVmns
    template-haskell-2.20.0.0 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
